pub fn setup_remote(
setup: &SetupRemote<'_>,
remote_id: &NodeId,
remote_name: Option<RefString>,
aliases: &impl AliasStore,
) -> Result<RefString>Expand description
Setup a remote and tracking branch for the given remote.
pub fn setup_remote(
setup: &SetupRemote<'_>,
remote_id: &NodeId,
remote_name: Option<RefString>,
aliases: &impl AliasStore,
) -> Result<RefString>Setup a remote and tracking branch for the given remote.