Element

Trait Element 

pub trait Element:
    Debug
    + Send
    + Sync {
    // Required methods
    fn size(&self, parent: Constraint) -> Size;
    fn render(&self, parent: Constraint) -> Vec<Line>;

    // Provided methods
    fn columns(&self, parent: Constraint) -> usize { ... }
    fn rows(&self, parent: Constraint) -> usize { ... }
    fn print(&self) { ... }
    fn write(&self, constraints: Constraint) -> Result<(), Error>
       where Self: Sized { ... }
    fn display(&self, constraints: Constraint) -> String { ... }
}
A text element that has a size and can be rendered to the terminal.

Required Methods

fn size(&self, parent: Constraint) -> Size

Get the size of the element, in rows and columns.

fn render(&self, parent: Constraint) -> Vec<Line>

Render the element as lines of text that can be printed.

Provided Methods

fn columns(&self, parent: Constraint) -> usize

Get the number of columns occupied by this element.

fn rows(&self, parent: Constraint) -> usize

Get the number of rows occupied by this element.

fn print(&self)

Print this element to stdout.

fn write(&self, constraints: Constraint) -> Result<(), Error>
where Self: Sized,

Write using the given constraints to stdout.

fn display(&self, constraints: Constraint) -> String

Return a string representation of this element.