println

Function println 

pub fn println(msg: impl Display)
Print a line to stdout, silently ignoring broken pipe errors.

Use this function instead of println! when you want to print to standard output, but silently ignore broken pipe errors.

See also self::print.

Panics

If writing to standard output fails with an error not of kind io::ErrorKind::BrokenPipe.