Module format

Module format 

Modules

html
HTML-related formatting.
identity
Identity formatting
issue
Issue formatting
patch
Patch formatting

Structs

Author
This enum renders (nid, alias) in terminal depending on user variant.
Identity
Identity formatter that takes a profile and displays it as <node-id> (<username>) depending on the configuration.
Paint
A structure encapsulating an item and styling.

Functions

badge_negative
badge_positive
badge_primary
badge_secondary
badge_yellow
bold
bytes
cob
Format a COB id.
command
Format a command suggestion, eg. rad init.
default
did
Format a DID.
dim
faint
highlight
hint
italic
negative
node_id_human
Format a node id.
node_id_human_compact
Format a node id to be more compact.
oid
Format a Git object identifier, shortened to the first 7 characters. To format a Git object identifier in long form, see oid_long.
oid_long
Format a Git object identifier. To format a Git object identifier in short form, see oid.
parens
Wrap parenthesis around styled input, eg. "input" -> "(input)".
policy
Format a policy.
positive
primary
range
Format a range between Git object identifiers (usually commits). Both object identifiers are formatted in short form, see oid. To format a range in long form, see range_long.
range_long
Format a range between Git object identifiers (usually commits). Both object identifiers are formatted in their long form, see oid_long. To format a range in short form, see range.
ref_update
Format a ref update.
ref_update_verbose
secondary
spaced
Wrap spaces around styled input, eg. "input" -> " input ".
style
tertiary
timestamp
Format a timestamp.
visibility
Format a Visibility.
wrap
yellow