range

Function range 

pub fn range<IntoOid>(base: IntoOid, head: IntoOid) -> Paint<String>
where IntoOid: Into<Oid>,
Format a range between Git object identifiers (usually commits). Both object identifiers are formatted in short form, see oid. To format a range in long form, see range_long.