Enums
Constants
Functions
- get_
create_ message - Get the Patch title and description from the command line arguments, or request it from the user.
- get_
edit_ message - Get a patch edit message.
- get_
update_ message - Get a patch update message.
- list_
commits - List the given commits in a table.
- message
- Combine the title and description fields to display to the user.
- patch_
commits - Return commits between the merge base and a head.
- print_
commits_ ahead_ behind - Print commits ahead and behind.
- show