pub struct Signature<'a> { /* private fields */ }Expand description
A Signature is used to indicate authorship of various actions throughout the library.
Signatures contain a name, email, and timestamp. All fields can be specified
with new while the now constructor omits the timestamp. The
Repository::signature method can be used to create a default signature
with name and email values read from the configuration.
Implementations
Sourceimpl<'a> Signature<'a>
impl<'a> Signature<'a>
Sourcepub fn now(name: &str, email: &str) -> Result<Signature<'static>, Error>
pub fn now(name: &str, email: &str) -> Result<Signature<'static>, Error>
Create a new action signature with a timestamp of ‘now’.
See new for more information
Sourcepub fn new(
name: &str,
email: &str,
time: &Time,
) -> Result<Signature<'static>, Error>
pub fn new( name: &str, email: &str, time: &Time, ) -> Result<Signature<'static>, Error>
Create a new action signature.
The time specified is in seconds since the epoch, and the offset is
the time zone offset in minutes.
Returns error if either name or email contain angle brackets.
Sourcepub fn name_bytes(&self) -> &[u8] ⓘ
pub fn name_bytes(&self) -> &[u8] ⓘ
Gets the name on the signature as a byte slice.
Sourcepub fn email_bytes(&self) -> &[u8] ⓘ
pub fn email_bytes(&self) -> &[u8] ⓘ
Gets the email on the signature as a byte slice.