pub fn print(msg: impl Display)Expand description
Print to stdout without a trailing newline, silently ignoring broken pipe errors.
Use this function instead of print! when you want to print to standard
output, but silently ignore broken pipe errors.
See also self::println.
Panics
If writing to standard output fails with an error not of kind io::ErrorKind::BrokenPipe.