range_long

Function range_long 

pub fn range_long<IntoOid>(base: IntoOid, head: IntoOid) -> Paint<String>
where IntoOid: Into<Oid>,
Format a range between Git object identifiers (usually commits). Both object identifiers are formatted in their long form, see oid_long. To format a range in short form, see range.