Module patch

Module patch 

Enums

Error
Message
The user supplied Patch description.

Constants

PATCH_MSG

Functions

get_create_message
Get the Patch title and description from the command line arguments, or request it from the user.
get_edit_message
Get a patch edit message.
get_update_message
Get a patch update message.
list_commits
List the given commits in a table.
message
Combine the title and description fields to display to the user.
patch_commits
Return commits between the merge base and a head.
print_commits_ahead_behind
Print commits ahead and behind.
show